@@ -3,8 +3,9 @@ from typing import cast, List
 
 from invoke import Collection, Context, Result, task
 
-from invokelint.path import PYTHON_DIRS, SOURCE_DIRS, TASKS_PY, TEST_DIR
+from invokelint.path import EXISTING_TEST_PACKAGES, PYTHON_DIRS, PYTHON_DIRS_EXCLUDING_TEST
 from invokelint.run import run_all, run_in_order, run_in_pty
+from invokelint.style import fmt
 
 ns = Collection()
 
@@ -51,8 +52,8 @@ ns.add_task(cohesion)
 def bandit(context: Context) -> Result:
     """Lints code with bandit."""
     space = " "
-    run_in_pty(context, "bandit --recursive {}".format(space.join([str(p) for p in [*SOURCE_DIRS, TASKS_PY]])))
-    return run_in_pty(context, "bandit --recursive --skip B101 {}".format(TEST_DIR))
+    run_in_pty(context, "bandit --recursive {}".format(space.join(PYTHON_DIRS_EXCLUDING_TEST)))
+    return run_in_pty(context, "bandit --recursive --skip B101 {}".format(space.join(EXISTING_TEST_PACKAGES)))
 
 
 @task
@@ -76,14 +77,16 @@ def pydocstyle(context: Context) -> Result:
 @task
 def xenon(context: Context) -> Result:
     """Checks code complexity."""
-    command = ("xenon" " --max-absolute A" "--max-modules A" "--max-average A" "{}").format(" ".join(PYTHON_DIRS))
+    command = ("xenon --max-absolute A --max-modules A --max-average A {}").format(" ".join(PYTHON_DIRS))
     return run_in_pty(context, command)
 
 
-@task
-def fast(context: Context) -> List[Result]:
+@task(help={"skip_format": "Lints without format style."})
+def fast(context: Context, skip_format: bool = False) -> List[Result]:
     """Runs fast linting (bandit, dodgy, flake8, pydocstyle, xenon)."""
-    return run_in_order([bandit, dodgy, flake8, pydocstyle, xenon], context)
+    list_result = [] if skip_format else fmt(context)
+    list_result.extend(run_in_order([bandit, dodgy, flake8, pydocstyle, xenon], context))
+    return list_result
 
 
 ns.add_task(bandit)
